@@ -20,9 +20,8 @@
 #' @param x A nested.glmnetr output object
 #' @param type determines what type of nested cross validation performance measures are 
 #' plotted.  Possible values are 
-#' "devrat" to plot the deviance ratio, i.e. the fractional reduction 
-#' in deviance relative to the null model deviance, 
-#' "devain" to plot deviance, 
+#' "devrat" to plot the deviance ratio, i.e. the fractional reduction in 
+#' deviance relative to the null model deviance, 
 #' "agree" to plot agreement in terms of concordance, correlation or R-square, 
 #' "lincal" to plot the linear calibration slope coefficients, 
 #' "intcal" to plot the linear calibration intercept coefficients, 
@@ -54,8 +53,7 @@
 #' 
 #' @noRd
 #' 
-plot_perf_glmnetr_0_6_1 = function( x, type="devrat", pow=2, ylim=1, fold=1, xgbsimple=0, plot=1, track=0 ) {
-  if (track >= 2) { cat( "  in plot_perf_glmnetr_0_6_1   class(x) = ", class(x), "\n") }
+plot_perf_glmnetr_0_5_5 = function( x, type="devrat", pow=2, ylim=1, fold=1, xgbsimple=0, plot=1 ) {
   
   object = x 
   
@@ -137,20 +135,15 @@ plot_perf_glmnetr_0_6_1 = function( x, type="devrat", pow=2, ylim=1, fold=1, xgb
       } else if (type == "devrat") {
         object1 = object$lasso.devian.rep
         devratl = list()
-        for (j_ in c(1:5)) {
+        for (j_ in c(1:7)) {
           devratl[[j_]] = devrat_(object1[,j_], m2.ll.null, m2.ll.sat, n__ ) ; object1[,j_] = devratl[[j_]][[1]]
         }
       }
       nfold = dim(object1)[1]
-      toplot1=                 cbind( rep(1,nfold) , c(1:nfold), object1[,1]) 
-      toplot1= rbind( toplot1, cbind( rep(2,nfold) , c(1:nfold), object1[,2]) ) 
-      toplot1= rbind( toplot1, cbind( rep(3,nfold) , c(1:nfold), object1[,3]) ) 
-      if (length(object$alpha) > 1) {
-        toplot1= rbind( toplot1, cbind( rep(4,nfold) , c(1:nfold), object1[,4]) ) 
-        toplot1= rbind( toplot1, cbind( rep(5,nfold) , c(1:nfold), object1[,5]) ) 
-      } else {
-        toplot1= rbind( toplot1, cbind( rep(4,nfold) , c(1:nfold), object1[,5]) ) 
-      }
+      toplot1= cbind( rep(1,nfold) , c(1:nfold), object1[,2]) 
+      toplot1= rbind( toplot1, cbind( rep(2,nfold) , c(1:nfold), object1[,4]) )
+      toplot1= rbind( toplot1, cbind( rep(3,nfold) , c(1:nfold), object1[,6]) )                
+      toplot1= rbind( toplot1, cbind( rep(4,nfold) , c(1:nfold), object1[,7]) )                                
       
       if        (type ==  "agree") {  object2 = object$lasso.agree.naive 
       } else if (type == "lincal") {  object2 = object$lasso.lincal.naive 
@@ -158,43 +151,30 @@ plot_perf_glmnetr_0_6_1 = function( x, type="devrat", pow=2, ylim=1, fold=1, xgb
       } else if (type == "devian") {  object2 = object$lasso.devian.naive
       } else if (type == "devrat") {
         object2 = object$lasso.devian.naive
-        for (j_ in c(1:5)) {
+        for (j_ in c(1:7)) {
           object2[j_] = devrat_(object2[j_], null.m2LogLik, sat.m2LogLik, 1 )[[2]]   
         }
       }
-      toplot2 =                 cbind( 1 , 1, object2[1]) 
-      toplot2 = rbind( toplot2, cbind( 2 , 1, object2[2]) ) 
-      toplot2 = rbind( toplot2, cbind( 3 , 1, object2[3]) ) 
-      i_ = 3 
-      if (length(object$alpha) > 1) { 
-        i_ = i_ + 1 
-        toplot2 = rbind( toplot2, cbind( i_ , 1, object2[4]) )
-      }
-      i_ = i_ + 1 
-      toplot2 = rbind( toplot2, cbind( i_ , 1, object2[5]) ) 
+      toplot2 = cbind( 1 , 1, object2[2]) 
+      toplot2 = rbind( toplot2, cbind( 2 , 1, object2[4]) )
+      toplot2 = rbind( toplot2, cbind( 3 , 1, object2[6]) )                
+      toplot2 = rbind( toplot2, cbind( 4 , 1, object2[7]) )                                
       
       object3 = colMeans(object1,na.rm=T)      
       if (type == "devrat") {
-        for (j_ in c(1:5)) {
+        for (j_ in c(1:7)) {
           object3[j_] = devratl[[j_]][[2]]
         }
       }
-      toplot3 =                 cbind( 1 , 1, object3[1], 1) 
-      toplot3 = rbind( toplot3, cbind( 2 , 1, object3[2], 1) ) 
-      toplot3 = rbind( toplot3, cbind( 3 , 1, object3[3], 1) )
-      i_ = 3 
-      if (length(object$alpha) > 1) { 
-        i_= i_ + 1
-        toplot3 = rbind( toplot3, cbind( i_ , 1, object3[4], 1) )
-      }
-      i_= i_ + 1
-      toplot3 = rbind( toplot3, cbind( i_ , 1, object3[5], 1) )
+      toplot3 = cbind( 1 , 1, object3[2], 1) 
+      toplot3 = rbind( toplot3, cbind( 2 , 1, object3[4], 1) ) 
+      toplot3 = rbind( toplot3, cbind( 3 , 1, object3[6], 1) )
+      toplot3 = rbind( toplot3, cbind( 4 , 1, object3[7], 1) ) 
       
-      nms = c("Lasso", "Relaxed", "G0 Relax", "Elastic Net", "Ridge")
-      if (length(object$alpha) <= 1) { nms = nms[-4] }
+      nms = c("Lasso", "Relaxed", "G0 Relax", "Ridge")
+      i_ = 4 
     }
     
-    toplot1
     toplot2
     toplot3
     
@@ -574,7 +554,7 @@ plot_perf_glmnetr_0_6_1 = function( x, type="devrat", pow=2, ylim=1, fold=1, xgb
     toplot3
     
     ##### Step Wise ##############################################################
-    if ( (object$fits[6] == 1) | (object$fits[7] == 1) | (object$fits[9] == 1) ) {
+    if ( (object$fits[6] == 1) | (object$fits[7] == 1) ) {
       if (is.null(object$step.devian.rep)) { object$step.devian.rep = object$step.devian.cv }
       if (is.null(object$step.lincal.rep)) { object$step.lincal.rep = object$step.lincal.cv }
       if (is.null(object$step.intcal.rep)) { object$step.intcal.rep = object$step.intcal.cv }
@@ -592,26 +572,26 @@ plot_perf_glmnetr_0_6_1 = function( x, type="devrat", pow=2, ylim=1, fold=1, xgb
       } else if (type == "devrat") {
         object1 = object$step.devian.rep
         devratl = list()
-        for (j_ in c(1:4)) {
+        for (j_ in c(1:3)) {
           devratl[[j_]] = devrat_(object1[,j_], m2.ll.null, m2.ll.sat, n__ ) ; object1[,j_] = devratl[[j_]][[1]]
         }
       }
       nfold = dim(object1)[1]    
       
       if        (type ==  "agree") {  object2 = object$step.agree.naive 
-      } else if (type == "lincal") {  object2 = c(1,1,1,1)
-      } else if (type == "intcal") {  object2 = c(0,0,0,0)
+      } else if (type == "lincal") {  object2 = c(1,1,1)
+      } else if (type == "intcal") {  object2 = c(0,0,0)
       } else if (type == "devian") {  object2 = object$step.devian.naive 
       } else if (type == "devrat") {
         object2 = object$step.devian.naive
-        for (j_ in c(1:4)) {
+        for (j_ in c(1:3)) {
           object2[j_] = devrat_(object2[j_], null.m2LogLik, sat.m2LogLik, 1 )[[2]]   
         }
       }
       
       object3 = colMeans(object1,na.rm=T)      
       if (type == "devrat") {
-        for (j_ in c(1:4)) {
+        for (j_ in c(1:3)) {
           object3[j_] = devratl[[j_]][[2]]
         }
       }
@@ -644,15 +624,6 @@ plot_perf_glmnetr_0_6_1 = function( x, type="devrat", pow=2, ylim=1, fold=1, xgb
       aic_which = i_ 
     }
     
-    if  (object$fits[9] == 1) {
-      i_ = i_ + 1 
-      toplot1= rbind( toplot1, cbind( rep(i_,nfold) , c(1:nfold), object1[,4]) )
-      toplot2 = rbind( toplot2, cbind( i_ , 1, object2[4]) )
-      toplot3 = rbind( toplot3, cbind( i_ , 1, object3[4], 1) )
-      nms[i_] = "Full"
-      full_which = i_ 
-    }
-    
     toplot3
     
     cbind(nms,toplot2)
